import Adw from 'gi://Adw';
import Gio from 'gi://Gio';
import Gtk from 'gi://Gtk';
import { ExtensionPreferences, gettext as _, } from 'resource:///org/gnome/Shell/Extensions/js/extensions/prefs.js';
import { Keys } from './keys.js';
export default class WindowDesaturationPreferences extends ExtensionPreferences {
    async fillPreferencesWindow(window) {
        window._settings = this.getSettings();
        const page = new Adw.PreferencesPage({
            title: _('General'),
            iconName: 'dialog-information-symbolic',
        });
        window.add(page);
        const group = new Adw.PreferencesGroup({
            title: _('Desaturation'),
            description: _('Configure desaturation'),
        });
        page.add(group);
        const overview = new Adw.SwitchRow({
            title: _('Overview'),
            subtitle: _('Whether to apply desaturation in the overview'),
        });
        group.add(overview);
        window._settings.bind(Keys.desaturate_overview, overview, 'active', Gio.SettingsBindFlags.DEFAULT);
        const background = new Adw.ActionRow({
            title: _('Background Amount'),
            subtitle: _('How much to desaturate background windows'),
        });
        group.add(background);
        const backgroundFactor = new Gtk.Scale({
            hexpand: true,
            orientation: Gtk.Orientation.HORIZONTAL,
            adjustment: new Gtk.Adjustment({
                lower: 0.0,
                upper: 1.0,
                step_increment: 0.05,
                page_increment: 0.25,
            }),
        });
        background.add_suffix(backgroundFactor);
        // FIXME: bind_with_mapping fails for some reason
        window._settings.bind(Keys.background_factor, backgroundFactor.adjustment, 'value', Gio.SettingsBindFlags.DEFAULT);
        const hover = new Adw.SwitchRow({
            title: _('Hover'),
            subtitle: _('Whether to apply custom desaturation on hover'),
        });
        group.add(hover);
        window._settings.bind(Keys.desaturate_hover, hover, 'active', Gio.SettingsBindFlags.DEFAULT);
        const hoverRow = new Adw.ActionRow({
            title: _('Hover Amount'),
            subtitle: _('How much to desaturate hovered windows'),
        });
        group.add(hoverRow);
        window._settings.bind(Keys.desaturate_hover, hoverRow, 'sensitive', Gio.SettingsBindFlags.DEFAULT);
        const hoverFactor = new Gtk.Scale({
            hexpand: true,
            orientation: Gtk.Orientation.HORIZONTAL,
            adjustment: new Gtk.Adjustment({
                lower: 0.0,
                upper: 1.0,
                step_increment: 0.05,
                page_increment: 0.25,
            }),
        });
        hoverRow.add_suffix(hoverFactor);
        // FIXME: bind_with_mapping fails for some reason
        window._settings.bind(Keys.hover_factor, hoverFactor.adjustment, 'value', Gio.SettingsBindFlags.DEFAULT);
    }
}
